@@ -12,14 +12,13 @@ and serializing live objects into MMIF JSON data. Specialized behavior
 for the different components of MMIF is added in the subclasses.
 """
 
-import logging
 import json
-
-from pyrsistent import pvector, m, pmap, s, PVector, PMap, PSet, thaw
+import logging
 from datetime import datetime
+from typing import Union, Any, Dict, Optional, TypeVar, Generic, Generator, Iterator
 
 from deepdiff import DeepDiff
-from typing import Union, Any, Dict, Optional, TypeVar, Generic, Generator, Iterator
+from pyrsistent import pvector, m, pmap, s, PVector, PMap, PSet, thaw
 
 T = TypeVar('T')
 
@@ -260,10 +259,13 @@ class MmifObject(object):
 
     def __eq__(self, other) -> bool:
         return isinstance(other, type(self)) and \
-               len(DeepDiff(self, other, ignore_order=True, report_repetition=True, exclude_types=[datetime])) == 0
+               len(DeepDiff(self, other, report_repetition=True, exclude_types=[datetime])) == 0
 
     def __len__(self) -> int:
-        return sum([not self.is_empty(self[named]) for named in self._named_attributes()]) \
+        """
+        Returns number of attributes that are not *empty*. 
+        """
+        return sum([named in self and not self.is_empty(self[named]) for named in self._named_attributes()]) \
                + (len(self._unnamed_attributes) if self._unnamed_attributes else 0)
 
     def __setitem__(self, key, value) -> None:
@@ -291,10 +293,15 @@ class MmifObject(object):
 
     def __getitem__(self, key) -> Union['MmifObject', str, datetime]:
         if key in self._named_attributes():
-            return self.__dict__[key]
-        if self._unnamed_attributes is None:
-            raise AttributeError(f"Additional properties are disallowed by {self.__class__}")
-        return self._unnamed_attributes[key]
+            value = self.__dict__[key]
+        elif self._unnamed_attributes is None:
+            raise AttributeError(f"Additional properties are disallowed by {self.__class__}: {key}")
+        else: 
+            value = self._unnamed_attributes[key]
+        if key not in self._required_attributes and self.is_empty(value):
+            raise KeyError(f"Property not found: {key} (is it set?)")
+        else: 
+            return value
 
 
 class FreezableMmifObject(MmifObject):
@@ -339,11 +346,11 @@ class FreezableMmifObject(MmifObject):
             nonlocal fully_frozen
 
             if isinstance(element, (list, PVector)):
-                return pvector(_pyrsist(item) for item in element)
+                return pvector(_pyrsist(item) for item in element)  # pytype: disable=attribute-error
             elif isinstance(element, (dict, PMap)):
-                return pmap({key: _pyrsist(value) for key, value in element.items()})
+                return pmap({key: _pyrsist(value) for key, value in element.items()})  # pytype: disable=attribute-error
             elif isinstance(element, FreezableMmifObject):
-                fully_frozen &= element.deep_freeze()
+                fully_frozen &= element.deep_freeze()  # pytype: disable=attribute-error
                 return element
             elif element is not None and (not hasattr(element, '__hash__')
                                           or element.__class__.__hash__ in {object.__hash__, None}):
